@@ -171,7 +171,7 @@ impl<I: GetSize> GetSize for RangeInclusive<I> {
 
 impl<T> GetSize for Cow<'_, T>
 where
-    T: ToOwned,
+    T: ToOwned + ?Sized,
     <T as ToOwned>::Owned: GetSize,
 {
     fn get_heap_size(&self) -> usize {
@@ -579,12 +579,30 @@ impl GetSize for Box<str> {
     }
 }
 
+impl<T> GetSize for Rc<[T]>
+where
+    T: GetSize,
+{
+    fn get_heap_size(&self) -> usize {
+        self.iter().map(GetSize::get_size).sum()
+    }
+}
+
 impl GetSize for Rc<str> {
     fn get_heap_size(&self) -> usize {
         self.len()
     }
 }
 
+impl<T> GetSize for Arc<[T]>
+where
+    T: GetSize,
+{
+    fn get_heap_size(&self) -> usize {
+        self.iter().map(GetSize::get_size).sum()
+    }
+}
+
 impl GetSize for Arc<str> {
     fn get_heap_size(&self) -> usize {
         self.len()
@@ -683,7 +701,36 @@ where
             return self.iter().map(GetSize::get_heap_size).sum();
         }
 
-        self.iter().map(GetSize::get_size).sum()
+        let mut total = self.iter().map(GetSize::get_size).sum();
+        let additional: usize = self.capacity() - self.len();
+        total += additional * A::Item::get_stack_size();
+        total
+    }
+}
+
+#[cfg(feature = "thin-vec")]
+impl<T> GetSize for thin_vec::ThinVec<T>
+where
+    T: GetSize,
+{
+    fn get_heap_size(&self) -> usize {
+        if self.capacity() == 0 {
+            // If it's the singleton we might not be a heap pointer.
+            return 0;
+        }
+
+        // The capacity and length are stored on the heap.
+        let mut total = std::mem::size_of::<usize>() * 2;
+
+        for v in self {
+            // We assume that value are hold inside the heap.
+            total += GetSize::get_size(v);
+        }
+
+        let additional: usize = self.capacity() - self.len();
+        total += additional * T::get_stack_size();
+
+        total
     }
 }
 
@@ -691,7 +738,7 @@ where
 impl GetSize for compact_str::CompactString {
     fn get_heap_size(&self) -> usize {
         if self.is_heap_allocated() {
-            self.len()
+            self.capacity()
         } else {
             0
         }
